pub struct AsyncQuantLoadContext {
pub metadata: AsyncIndexMetadata,
pub num_frozen_points: NonZeroUsize,
pub metric: Metric,
pub prefetch_lookahead: Option<usize>,
pub is_disk_index: bool,
pub prefetch_cache_line_level: Option<PrefetchCacheLineLevel>,
}Expand description
Indicates that the canonical layout for a Quant index is expected for deserialization.
For a file-path prefix prefix, this layout includes the following files:
Common:
prefix: The file that contains the saved graph.prefix.data: The serialized full-precision data in.binform.
Depending on the quantization method used, one of the following sets of files will also be present:
If Product Quantization (PQ) is used:
prefix_build_pq_pivots.bin: The saved PQ pivot table.prefix_build_pq_compressed.bin: The saved PQ codes.
If Scalar Quantization (SQ) is used:
prefix_sq_compressed.bin: The saved scalar quantized codes.prefix_scalar_quantizer_proto.bin: The saved scalar quantizer metadata.
Fields
metadata: AsyncIndexMetadataThe file path prefix of the index.
num_frozen_points: NonZeroUsizeThe number of frozen points stored in the datasets.
metric: MetricThe metric to use for this index.
prefetch_lookahead: Option<usize>The number of iterations to prefetch when performing bulk-retrievals.
is_disk_index: boolTemporary parameter to indicate if the index is a disk index to load right file names. This can be removed once disk index uses same file names as async index.
prefetch_cache_line_level: Option<PrefetchCacheLineLevel>controls the prefetch cache line level for the index.